#
# spec file for package argon2
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch i686 x86_64
%define no_optimize 0
%else
%define no_optimize 1
%endif
# for convenience
%define make %__make %{?_smp_mflags} OPTFLAGS="%{optflags}" OPTTEST=%no_optimize LIB_ST= LIBRARY_REL=%_lib

%define lname libargon2-1
Name:           argon2
VCS: https://src.suse.de/pool/argon2#e9e3f41d8bb2d75a4d96cb734d670fcc184b5951
Version:        20190702
Release:        2.7
Summary:        The reference C implementation of Argon2
License:        Apache-2.0 OR CC0-1.0
Group:          Productivity/Networking/Security
URL:            https://github.com/P-H-C/phc-winner-argon2
Source:         https://github.com/P-H-C/phc-winner-argon2/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE adjust-makefile.patch -- Allow setting optflags and file permissions of installed libraries
Patch1:         adjust-makefile.patch
BuildRequires:  pkgconfig
BuildRequires:  sed
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is the reference C implementation of Argon2, the password-hashing function
that won the Password Hashing Competition (PHC) in 2015.

Argon2 is a password hashing function that is parametrized by a time cost, a
memory cost and a parallelism degree, used to guard against side-channel
attacks, attacks where lots of memory is available, or attacks where a lot of
processing is available.

%package doc
Summary:        Documentation for Argon2
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Documentation for Argon2, the password hashing function that won the Password
Hashing Competition (PHC) in 2015.

%package -n %{lname}
Summary:        The reference C implementation of Argon2
Group:          System/Libraries

%description -n %{lname}
Reference C implementation of Argon2, the password-hashing function
that won the Password Hashing Competition (PHC) in 2015.

%package devel
Summary:        Development files for argon2
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Headers for argon2, the reference C implementation of Argon2, the
password hashing function that won the Password Hashing Competition
(PHC) in 2015.

%prep
%setup -n phc-winner-argon2-%version
%patch1 -p1

%build
%make

%install
%make install DESTDIR=%{buildroot}

install -D -m 644 man/argon2.1 %{buildroot}%{_mandir}/man1/argon2.1

%check
%make test

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/argon2
%{_mandir}/man1/argon2.1%{ext_man}

%files doc
%defattr(-,root,root)
%doc argon2-specs.pdf

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/libargon2.so.1

%files devel
%defattr(-,root,root)
%{_includedir}/argon2.h
%{_libdir}/libargon2.so
%{_libdir}/pkgconfig/libargon2.pc

%changelog
* Wed Apr 27 2022 meissner@suse.com
- use a source url
* Sat Apr 23 2022 rpm@fthiessen.de
- Fix version of package: 20171227 is the upstream version number
  of the package
- Replaced optflags.patch with adjust-makefile.patch, the
  patch will now also allow to set the file permissions of installed
  libraries. This fixes the rpmlint error: shared-library-not-executable
* Tue May 12 2020 wolfgang.frisch@suse.com
- Update to version 0.0+git20190520.62358ba (boo#1170512):
  * Fix the Makefile to install libargon2.pc.
  * Wait for already running threads if a thread creation failed.
  * Added Argon2 Erlang binding.
  * Additional JVM bindings (Jargon2).
* Tue Jan 30 2018 lnussel@suse.de
- add baselibs.conf as cryptsetup also has 32bit variants
* Tue Jan  9 2018 jengelh@inai.de
- Update description.
* Tue Jan  9 2018 lnussel@suse.de
- Update to version 0.0+git20171227.670229c:
  * Added ABI version number
  * AVX2/AVX-512F optimizations of BLAMKA
  * Set Argon2 version number from the command line
  * New bindings
  * Minor bug and warning fixes (no security issue)
- use _service file
* Tue Apr 18 2017 meissner@suse.com
- ship libargon2.pc (bsc#1034441)
* Thu Feb 23 2017 adam@mizerski.pl
- moved argon2-specs.pdf to doc subpackage
- added packaging of man page
* Sat Jan 28 2017 hpj@urpla.net
- make sure to call cc with -pthread option (implies -lpthread)
- run test suite
* Tue Dec 20 2016 idonmez@suse.com
- Initial release
